# ANALYTICAL DATASET GENERATION
#
# R script used to generate the analytical dataset from the full ANRS 12361
# PrEP-CI dataset (version 2.0, DOI: 10.5281/zenodo.5948841).

library(tidyverse)
library(labelled)

d <- haven::read_sav("data_prepci_v2.0.0/Questionnaires Individuels.sav") %>%
  unlabelled()

d <- d %>%
  mutate(
    overall = "overall population",
    region = PRE_CLE %>%
      str_sub(1, 1) %>%
      factor(levels = c("A", "C"), labels = c("San Pedro", "Abidjan")),
    age_group = if_else(PAT_AGE < 25, "24 years or less", "25 years or more"),
    education = DEM_SCO %>%
      fct_recode(
        "never been to school" = "Jamais scolarisée",
        "primary" = "Primaire",
        "secondary / university" = "Secondaire",
        "secondary / university" = "Supérieur"
      ),
    nationality = PAT_NAT %>%
      fct_recode(
        "Ivorian" = "Ivoirienne",
        "other nationality" = "Etrangère"
      ),
    years_sex_work = if_else(
      PRA_SEX_TEM_AN < 4, 
      "3 years or less", 
      "4 years or more"
    ),
    usual_price = if_else(
      PRA_SEX_PRI_HAB < 2000, 
      "1999 FCFA (~3€) or less", 
      "2000 FCFA (~3€) or more"
    ),
    recruitment_site = LIE_REC %>%
      fct_recode(
        "brothel" = "Maison close",
        "bar / “maquis”" = "Bar - maquis",
        "other" = "Plage",
        "street" = "Trottoir (rue)",
        "hotel" = "Hôtel",
        "other" = "Unité mobile",
        "other" = "Clinique de confiance",
        "other" = "Autre"
      ) %>%
      fct_relevel("brothel", "hotel", "bar / “maquis”", "street", "other"),
    clients_last_workday = case_when(
      PRA_SEX_NBR_CLI_DER < 2 ~ "1 client",
      PRA_SEX_NBR_CLI_DER >= 2 & PRA_SEX_NBR_CLI_DER < 7 ~ "2-6 clients",
      PRA_SEX_NBR_CLI_DER >= 7 ~ "7 clients or more"
    ),
    condom_use_clients = PRA_SEX_CAP %>%
      fct_recode(
        "never / sometimes / often" = "Jamais",
        "never / sometimes / often" = "Parfois",
        "never / sometimes / often" = "Souvent",
        "always" = "Toujours",
        NULL = "Ne sait pas",
        NULL = "Refus de répondre"
      ),
    condomless_for_money = PRA_SEX_CLI_SAN_CAP %>%
      fct_recode(
        "never" = "Jamais",
        "sometimes" = "Parfois",
        "often / always" = "Souvent",
        "often / always" = "Touours",
        NULL = "Ne sait pas",
        NULL = "Refus de répondre"
      ),
    sti = SER_SAN_INF_IST %>%
      fct_recode(
        "yes, at least one" = "Oui",
        "none" = "Non",
        NULL = "Ne sait pas",
        NULL = "Refus de répondre"
      ),
    several_cities = PRA_SEX_TRA_VIL %>%
      fct_recode(
        "yes, 2 cities or more" = "oui",
        "no, 1 city only" = "non"
      ),
    last_medical_visit = SER_SAN_CON_MED %>%
      fct_recode(
        "less than a year" = "Moins de 3 mois",
        "less than a year" = "3-12 mois",
        "more than a year or never consulted" = "Plus d'1 an",
        "more than a year or never consulted" = "Jamais consulté"
      ),
    
    hiv_negative = DEP_VIH_VIK == "Négatif",
    hiv_positive = DEP_VIH_VIK == "Positif",
    hiv_recent = VIH_INFECTION_RECENTE == "Oui"
  )%>%
  select(overall:hiv_recent)


write_csv(d, file = "analytical_dataset.csv")
